Strong Orthogonal Arrays of Strength t using the method of Liu and Liu
OSOA_LiuLiut(oa, t = NULL, m = NULL, permlist = NULL, random = TRUE)an orthogonal array
matrix or data.frame that contains an ingoing symmetric OA. Levels must be denoted as 0 to s-1 or as 1 to s.
strength of oa. If NULL (default), t will be
determined. t can be chosen smaller than the input strength if
additional columns are desired.
desired number of columns. Defaults to the maximum possible.
a list of length m of lists of length 1 of permutations of the levels
a logical (a random draw of permutations is used if permlist is NULL)
Suitable OAs for argument oa can e.g. be constructed with OA creation functions
from package lhs or can be obtained from arrays listed in R package DoE.base.
Liu and Liu (2015)