matrix or data.frame that contains an ingoing symmetric OA. Levels must be denoted as 0 to s-1 or as 1 to s.
ell
the multiplier for each number of levels
noptim.oa
integer: number of optimization rounds applied to initial oa itself before starting expansion
nseq
tuning parameters for TA algorithm
nrounds
tuning parameters for TA algorithm
nsteps
tuning parameters for TA algorithm
dmethod
distance method for phi_p, "manhattan" (default) or "euclidean"
p
p for phi_p (the larger, the closer to maximin distance)
Dc
matrix
Dp
matrix
s
original number of levels
Fhat
distribution function (created with createF)
Details
The ingoing oa is optimized by function phi_optimize,
using noptim.rounds=noptim.oa; this yields the matrix Dp for use
in the internal functions DcFromDp and createF.
Function XiaoXuMDLE returns the value
that is produced by applying the internal function optimize
to the resulting Dc and F.